@@ -1,9 +1,13 @@
 package ParseUtil::Domain;
-$ParseUtil::Domain::VERSION = '2.413';
-# VERSION
+
+## no critic
+our $VERSION = '2.42';
+$VERSION = eval $VERSION;
+## use critic
+
+use Carp;
 
 use Modern::Perl;
-use Carp;
 use utf8::all;
 use autobox;
 use autobox::Core;
@@ -76,7 +80,7 @@ sub puny_convert : Export(:simple) {
 sub _find_zone {
     my $domain_segments = shift;
 
-    my $tld_regex = ParseUtil::Domain::ConfigData->tld_regex();
+    my $tld_regex = ParseUtil::Domain::ConfigData->config('tld_regex');
     ### Domain Segments: $domain_segments
     my $tld  = $domain_segments->pop;
     my $sld  = $domain_segments->pop;
@@ -219,7 +223,6 @@ sub _puny_decode {
 
 }
 
-1;
 __END__
 
 =encoding utf8
