@@ -2,17 +2,16 @@ package ParseDomain;
 
 use strict;
 use warnings;
-use 5.010;
 
 use parent qw(Test::Class);
 
-use perl5i::2;
+use Modern::Perl;
+use utf8::all;
 use Test::More;
 
-#use Test::Deep ();
 use Test::Exception;
 #use Smart::Comments;
-
+binmode(STDOUT, "utf8");
 
 use ParseUtil::Domain ':parse';
 
@@ -98,78 +97,78 @@ sub t010_split_ascii_domain_tld : Test(33) {
 sub t020_split_unicode_domain_tld : Test(24) {
     my $self          = shift;
     my $domain_to_ace = [
-        #{
-            #raw     => 'ü.com',
-            #decoded => 'ü.com',
-            #ace     => 'xn--tda.com'
+        {
+            raw     => 'ü.com',
+            decoded => 'ü.com',
+            ace     => 'xn--tda.com'
 
-        #},
-        #{
-            #raw     => 'test.香港',
-            #decoded => 'test.香港',
-            #ace     => 'test.xn--j6w193g'
+        },
+        {
+            raw     => 'test.香港',
+            decoded => 'test.香港',
+            ace     => 'test.xn--j6w193g'
 
-        #},
-        #{
-            #raw     => 'test.敎育.hk',
-            #decoded => 'test.敎育.hk',
-            #ace     => 'test.xn--lcvr32d.hk'
+        },
+        {
+            raw     => 'test.敎育.hk',
+            decoded => 'test.敎育.hk',
+            ace     => 'test.xn--lcvr32d.hk'
 
-        #},
+        },
         {
             raw     => 'test.xn--o3cw4h',
             decoded => 'test.ไทย',
             ace     => 'test.xn--o3cw4h'
 
         },
-        #{
-            #raw     => 'ü@somewhere.name',
-            #decoded => 'ü@somewhere.name',
-            #ace     => 'xn--tda@somewhere.name'
+        {
+            raw     => 'ü@somewhere.name',
+            decoded => 'ü@somewhere.name',
+            ace     => 'xn--tda@somewhere.name'
 
-        #},
-        #{
-            #raw     => 'ü.or.at',
-            #decoded => 'ü.or.at',
-            #ace     => 'xn--tda.or.at'
+        },
+        {
+            raw     => 'ü.or.at',
+            decoded => 'ü.or.at',
+            ace     => 'xn--tda.or.at'
 
-        #},
+        },
         {
             decoded => 'bloß.de',
             ace     => 'xn--blo-7ka.de',
             raw     => 'xn--blo-7ka.de'
 
         },
-        #{
-            #raw     => 'faß.co.at',
-            #decoded => 'fass.co.at',
-            #ace     => 'fass.co.at'
+        {
+            raw     => 'faß.co.at',
+            decoded => 'fass.co.at',
+            ace     => 'fass.co.at'
 
-        #},
-        #{
-            #raw     => 'faß.de',
-            #decoded => 'faß.de',
-            #ace     => 'xn--fa-hia.de'
+        },
+        {
+            raw     => 'faß.de',
+            decoded => 'faß.de',
+            ace     => 'xn--fa-hia.de'
 
-        #},
-        #{
-            #decoded => 'faß.de',
-            #ace     => 'xn--fa-hia.de',
-            #raw     => 'xn--fa-hia.de'
+        },
+        {
+            decoded => 'faß.de',
+            ace     => 'xn--fa-hia.de',
+            raw     => 'xn--fa-hia.de'
 
-        #},
-        #{
-            #decoded => 'faß.fr',
-            #ace     => 'xn--fa-hia.fr',
-            #raw     => 'xn--fa-hia.fr'
+        },
+        {
+            decoded => 'faß.fr',
+            ace     => 'xn--fa-hia.fr',
+            raw     => 'xn--fa-hia.fr'
 
-        #},
-        #{
-            #decoded => 'faß.yt',
-            #ace     => 'xn--fa-hia.yt',
-            #raw     => 'xn--fa-hia.yt'
+        },
+        {
+            decoded => 'faß.yt',
+            ace     => 'xn--fa-hia.yt',
+            raw     => 'xn--fa-hia.yt'
 
-        #},
+        },
 
     ];
 
@@ -182,7 +181,7 @@ sub t020_split_unicode_domain_tld : Test(24) {
         my $ace_domain     = join "." => $domain_ace, $zone_ace;
 
         is( $test_domain->{decoded},
-            $decoded_domain, "Expected " . $test_domain->{decoded} );
+            $decoded_domain, "Got expected domain");
         is( $test_domain->{ace}, $ace_domain,
             "Expected " . $test_domain->{ace} );
 
